@@ -613,59 +613,60 @@ def path_to_recognition(
                 last_entity.raw_tokens.append(raw_token)
 
         # Handle converted (output) token
-        if conv_token:
+        if conv_token is not None:
             conv_token_str = str(conv_token)
-            if conv_token_str.startswith("__begin__"):
-                # Begin tag/entity
-                entity_name = conv_token[9:]
-                entity_stack.append(
-                    Entity(
-                        entity=entity_name,
-                        value="",
-                        start=sub_index,
-                        raw_start=raw_index,
+            if conv_token_str:
+                if conv_token_str.startswith("__begin__"):
+                    # Begin tag/entity
+                    entity_name = conv_token[9:]
+                    entity_stack.append(
+                        Entity(
+                            entity=entity_name,
+                            value="",
+                            start=sub_index,
+                            raw_start=raw_index,
+                        )
                     )
-                )
-            elif conv_token_str.startswith("__end__"):
-                # End tag/entity
-                assert entity_stack, "Found __end__ without a __begin__"
-                last_entity = entity_stack.pop()
-                actual_name = conv_token[7:]
-                assert (
-                    last_entity.entity == actual_name
-                ), "Mismatched entity name (expected {last_entity.entity}, got {actual_name})"
+                elif conv_token_str.startswith("__end__"):
+                    # End tag/entity
+                    assert entity_stack, "Found __end__ without a __begin__"
+                    last_entity = entity_stack.pop()
+                    actual_name = conv_token[7:]
+                    assert (
+                        last_entity.entity == actual_name
+                    ), "Mismatched entity name (expected {last_entity.entity}, got {actual_name})"
 
-                # Assign end indexes
-                last_entity.end = sub_index - 1
-                last_entity.raw_end = raw_index - 1
+                    # Assign end indexes
+                    last_entity.end = sub_index - 1
+                    last_entity.raw_end = raw_index - 1
 
-                # Create values
-                if len(last_entity.tokens) == 1:
-                    # Use Python object
-                    last_entity.value = last_entity.tokens[0]
-                else:
-                    # Join as string
-                    last_entity.value = " ".join(str(t) for t in last_entity.tokens)
+                    # Create values
+                    if len(last_entity.tokens) == 1:
+                        # Use Python object
+                        last_entity.value = last_entity.tokens[0]
+                    else:
+                        # Join as string
+                        last_entity.value = " ".join(str(t) for t in last_entity.tokens)
 
-                last_entity.raw_value = " ".join(last_entity.raw_tokens)
+                    last_entity.raw_value = " ".join(last_entity.raw_tokens)
 
-                # Add to recognition
-                recognition.entities.append(last_entity)
-            elif conv_token_str.startswith("__source__"):
-                if entity_stack:
+                    # Add to recognition
+                    recognition.entities.append(last_entity)
+                elif conv_token_str.startswith("__source__"):
+                    if entity_stack:
+                        last_entity = entity_stack[-1]
+                        last_entity.source = conv_token_str[10:]
+                elif entity_stack:
+                    # Add to most recent named entity
                     last_entity = entity_stack[-1]
-                    last_entity.source = conv_token_str[10:]
-            elif entity_stack:
-                # Add to most recent named entity
-                last_entity = entity_stack[-1]
-                last_entity.tokens.append(conv_token)
+                    last_entity.tokens.append(conv_token)
 
-                recognition.tokens.append(conv_token)
-                sub_index += len(conv_token_str) + 1
-            else:
-                # Substituted text
-                recognition.tokens.append(conv_token)
-                sub_index += len(conv_token_str) + 1
+                    recognition.tokens.append(conv_token)
+                    sub_index += len(conv_token_str) + 1
+                else:
+                    # Substituted text
+                    recognition.tokens.append(conv_token)
+                    sub_index += len(conv_token_str) + 1
 
     # Step 4: create text fields and compute confidence
     recognition.text = " ".join(str(t) for t in recognition.tokens)
@@ -683,12 +684,17 @@ def path_to_recognition(
 # -----------------------------------------------------------------------------
 
 
+def bool_converter(obj: typing.Any) -> bool:
+    """Returns False if argument is 'false' string or zero."""
+    return (obj != 0) and (str(obj).lower() != "false")
+
+
 def get_default_converters() -> typing.Dict[str, typing.Callable[..., typing.Any]]:
     """Get built-in fsticuffs converters"""
     return {
         "int": lambda *args: map(int, args),
         "float": lambda *args: map(float, args),
-        "bool": lambda *args: map(bool, args),
+        "bool": lambda *args: map(bool_converter, args),
         "lower": lambda *args: map(str.lower, args),
         "upper": lambda *args: map(str.upper, args),
         "object": lambda *args: [
